@@ -3,6 +3,7 @@ import json
 import pandas as pd
 import numpy as np
 import shutil
+import earthpy as et
 
 from steam_nb_api.resources.ResourceReader import ResourceReader
 from steam_nb_api.utils.misc import makeCopyFile
@@ -429,6 +430,7 @@ class ParametersCOSIM:
                 f.write('\n')
 
     def copyCOSIMfiles(self, circuit, nameFileSING, StimulusFile, LEDETFiles, nameMagnet,N_LEDET=1):
+        print(et.io.HOME)
         nameFolderCosimModel = os.path.join(os.getcwd(), 'cosim_model_' + circuit)
         print(nameFolderCosimModel)
         # Copy PSPICE model file
